﻿using System;
using Microsoft.EntityFrameworkCore.Migrations;
using Npgsql.EntityFrameworkCore.PostgreSQL.Metadata;

namespace Internship.Repository.Migrations
{
    public partial class InitialCreate : Migration
    {
        protected override void Up(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.CreateTable(
                name: "companies",
                columns: table => new
                {
                    nip = table.Column<string>(nullable: false),
                    name = table.Column<string>(nullable: true),
                    range = table.Column<int>(nullable: false),
                    site_address = table.Column<string>(nullable: true),
                    provider = table.Column<int>(nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("pk_companies", x => x.nip);
                });

            migrationBuilder.CreateTable(
                name: "course",
                columns: table => new
                {
                    id = table.Column<int>(nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn),
                    name = table.Column<string>(nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("pk_course", x => x.id);
                });

            migrationBuilder.CreateTable(
                name: "editions",
                columns: table => new
                {
                    id = table.Column<int>(nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn),
                    start_date = table.Column<DateTime>(nullable: false),
                    end_date = table.Column<DateTime>(nullable: false),
                    ipp_deadline_date = table.Column<DateTime>(nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("pk_editions", x => x.id);
                });

            migrationBuilder.CreateTable(
                name: "reports",
                columns: table => new
                {
                    id = table.Column<int>(nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn)
                },
                constraints: table =>
                {
                    table.PrimaryKey("pk_reports", x => x.id);
                });

            migrationBuilder.CreateTable(
                name: "branch_office",
                columns: table => new
                {
                    id = table.Column<int>(nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn),
                    street = table.Column<string>(nullable: true),
                    building = table.Column<string>(nullable: true),
                    city = table.Column<string>(nullable: true),
                    postal_code = table.Column<string>(nullable: true),
                    country = table.Column<string>(nullable: true),
                    company_nip = table.Column<string>(nullable: true),
                    provider = table.Column<int>(nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("pk_branch_office", x => x.id);
                    table.ForeignKey(
                        name: "fk_branch_office_companies_company_nip",
                        column: x => x.company_nip,
                        principalTable: "companies",
                        principalColumn: "nip",
                        onDelete: ReferentialAction.Restrict);
                });

            migrationBuilder.CreateTable(
                name: "interns",
                columns: table => new
                {
                    album_number = table.Column<string>(nullable: false),
                    name = table.Column<string>(nullable: true),
                    surname = table.Column<string>(nullable: true),
                    email = table.Column<string>(nullable: true),
                    course_id = table.Column<int>(nullable: true),
                    semester = table.Column<int>(nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("pk_interns", x => x.album_number);
                    table.ForeignKey(
                        name: "fk_interns_course_course_id",
                        column: x => x.course_id,
                        principalTable: "course",
                        principalColumn: "id",
                        onDelete: ReferentialAction.Restrict);
                });

            migrationBuilder.CreateTable(
                name: "internships",
                columns: table => new
                {
                    id = table.Column<int>(nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn),
                    intern_album_number = table.Column<string>(nullable: true),
                    edition_id = table.Column<int>(nullable: true),
                    report_id = table.Column<int>(nullable: true),
                    branch_office_id = table.Column<int>(nullable: true),
                    type = table.Column<int>(nullable: false),
                    start_date = table.Column<DateTime>(nullable: false),
                    end_date = table.Column<DateTime>(nullable: false),
                    is_accepted = table.Column<bool>(nullable: false),
                    acceptance_date = table.Column<DateTime>(nullable: true),
                    is_deans_acceptance_required = table.Column<bool>(nullable: true),
                    reason = table.Column<int>(nullable: true),
                    insurance_delivery_date = table.Column<DateTime>(nullable: true),
                    is_insurance_required = table.Column<bool>(nullable: true),
                    internship_length_in_weeks = table.Column<int>(nullable: false),
                    grade = table.Column<float>(nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("pk_internships", x => x.id);
                    table.ForeignKey(
                        name: "fk_internships_branch_office_branch_office_id",
                        column: x => x.branch_office_id,
                        principalTable: "branch_office",
                        principalColumn: "id",
                        onDelete: ReferentialAction.Restrict);
                    table.ForeignKey(
                        name: "fk_internships_editions_edition_id",
                        column: x => x.edition_id,
                        principalTable: "editions",
                        principalColumn: "id",
                        onDelete: ReferentialAction.Restrict);
                    table.ForeignKey(
                        name: "fk_internships_interns_intern_album_number",
                        column: x => x.intern_album_number,
                        principalTable: "interns",
                        principalColumn: "album_number",
                        onDelete: ReferentialAction.Restrict);
                    table.ForeignKey(
                        name: "fk_internships_reports_report_id",
                        column: x => x.report_id,
                        principalTable: "reports",
                        principalColumn: "id",
                        onDelete: ReferentialAction.Restrict);
                });

            migrationBuilder.CreateTable(
                name: "internship_program_subject",
                columns: table => new
                {
                    id = table.Column<int>(nullable: false)
                        .Annotation("Npgsql:ValueGenerationStrategy", NpgsqlValueGenerationStrategy.IdentityByDefaultColumn),
                    course_id = table.Column<int>(nullable: true),
                    description = table.Column<string>(nullable: true),
                    edition_id = table.Column<int>(nullable: true),
                    internship_entity_id = table.Column<int>(nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("pk_internship_program_subject", x => x.id);
                    table.ForeignKey(
                        name: "fk_internship_program_subject_course_course_id",
                        column: x => x.course_id,
                        principalTable: "course",
                        principalColumn: "id",
                        onDelete: ReferentialAction.Restrict);
                    table.ForeignKey(
                        name: "fk_internship_program_subject_editions_edition_id",
                        column: x => x.edition_id,
                        principalTable: "editions",
                        principalColumn: "id",
                        onDelete: ReferentialAction.Restrict);
                    table.ForeignKey(
                        name: "fk_internship_program_subject_internships_internship_entity_id",
                        column: x => x.internship_entity_id,
                        principalTable: "internships",
                        principalColumn: "id",
                        onDelete: ReferentialAction.Restrict);
                });

            migrationBuilder.CreateIndex(
                name: "ix_branch_office_company_nip",
                table: "branch_office",
                column: "company_nip");

            migrationBuilder.CreateIndex(
                name: "ix_interns_course_id",
                table: "interns",
                column: "course_id");

            migrationBuilder.CreateIndex(
                name: "ix_internship_program_subject_course_id",
                table: "internship_program_subject",
                column: "course_id");

            migrationBuilder.CreateIndex(
                name: "ix_internship_program_subject_edition_id",
                table: "internship_program_subject",
                column: "edition_id");

            migrationBuilder.CreateIndex(
                name: "ix_internship_program_subject_internship_entity_id",
                table: "internship_program_subject",
                column: "internship_entity_id");

            migrationBuilder.CreateIndex(
                name: "ix_internships_branch_office_id",
                table: "internships",
                column: "branch_office_id");

            migrationBuilder.CreateIndex(
                name: "ix_internships_edition_id",
                table: "internships",
                column: "edition_id");

            migrationBuilder.CreateIndex(
                name: "ix_internships_intern_album_number",
                table: "internships",
                column: "intern_album_number");

            migrationBuilder.CreateIndex(
                name: "ix_internships_report_id",
                table: "internships",
                column: "report_id");
        }

        protected override void Down(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.DropTable(
                name: "internship_program_subject");

            migrationBuilder.DropTable(
                name: "internships");

            migrationBuilder.DropTable(
                name: "branch_office");

            migrationBuilder.DropTable(
                name: "editions");

            migrationBuilder.DropTable(
                name: "interns");

            migrationBuilder.DropTable(
                name: "reports");

            migrationBuilder.DropTable(
                name: "companies");

            migrationBuilder.DropTable(
                name: "course");
        }
    }
}
